@@ -245,7 +245,7 @@ def _make_jobs_that_produce_vcf(
 
         import_gvcfs_job = _add_import_gvcfs_job(
             b=b,
-            genomicsdb_gcs_path=b.read_input(genomicsdb_gcs_path),
+            genomicsdb_gcs_path=genomicsdb_gcs_path,
             sample_name_map=b.read_input(sample_map_fpath),
             interval=intervals[f'interval_{idx}'],
         )
@@ -317,7 +317,6 @@ def find_inputs(
     subprocess.run(f'gsutil cp {ped_fpath} {local_ped_fpath}', check=False, shell=True)
     df = pd.read_csv(local_ped_fpath, delimiter='\t')
     shutil.rmtree(local_tmp_dir)
-    df['gvcf'] = ''
     df = df.set_index('Individual.ID', drop=False)
     df = df.rename(columns={'Individual.ID': 's'})
 
